<div dir="rtl">

# <p dir="rtl">pySentiPers</p>

<p dir="rtl">
Python API for SentiPers Dataset - رابط برنامه‌نویسی کاربردی پایتون مجموعه داده‌ی سنتی‌پرس

</p>

## مقدمه

پروژه‌ای که مشاهده می‌کنید یک API برای استفاده‌ی راحت‌تر از دیتاست سنتی‌پرس(SentiPers) به زبان پایتون می‌باشد. این مجموعه دادگان در گروه پردازش زبان‌های طبیعی دانشگاه گیلان به کوشش پدرام حسینی و همکاران تهیه شده است و در [اینجا](https://github.com/phosseini/SentiPers) اطلاعات بیشتری قابل مشاهده است.


## توضیحات
برای تهیه‌ی مجموعه به لینک بالا مراجعه کنید، این پروژه صرفا API پایتون برای کار با مجموعه دادگان می‌باشد.
پروژه‌ی حاضر توسط جواد زارع‌زاده نوشته شده است. چنانچه هم‌فکری و یا درخواستی برای اصلاح کد داشتید خوشحال خواهم شد با ایمیل زیر با من در ارتباط باشید.


<jvd.zarezadeh@gmail.com>
## نحوه‌ی نصب
این پروژه بر روی PyPI قرار گرفته و می‌توانید آن را با استفاده از ابزار pip نصب کنید.

<div dir="ltr">

```bash
pip install pysentipers
```

</div>
</div>
